POP
===

.. currentmodule:: xeofs.single

.. autoclass:: POP
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~POP.__init__
      ~POP.components
      ~POP.components_amplitude
      ~POP.components_phase
      ~POP.compute
      ~POP.damping_times
      ~POP.deserialize
      ~POP.eigenvalues
      ~POP.fit
      ~POP.fit_transform
      ~POP.get_params
      ~POP.get_serialization_attrs
      ~POP.inverse_transform
      ~POP.load
      ~POP.periods
      ~POP.save
      ~POP.scores
      ~POP.scores_amplitude
      ~POP.scores_phase
      ~POP.serialize
      ~POP.transform
   
   

   
   
   